@@ -7,10 +7,7 @@
 #'
 #' @export
 annotate_repostitle_active <- function() {
-  context <- rstudioapi::getActiveDocumentContext()
-  if (context[1]$id == "#console") {
-    stop("Focus (blinking cursor) is not on an open R file")
-  }
+  context <- rstudioapi::getSourceEditorContext()
   contents_parsed <- paste0(context$contents, sep = "\n", collapse = "")
   out <- annotater::annotate_repostitle(contents_parsed)
   outlines <- stringi::stri_split_lines1(out)
